/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.namingserver.entity.bo;

import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;

public class ClusterBO {

    Set<String> unitNames = ConcurrentHashMap.newKeySet();

    public ClusterBO(Set<String> unitNames) {
        this.unitNames = unitNames;
    }

    public ClusterBO() {}

    public Set<String> getUnitNames() {
        return unitNames;
    }

    public void setUnitNames(Set<String> unitNames) {
        this.unitNames = unitNames;
    }

    public void remove(String realUnitName) {
        this.unitNames.remove(realUnitName);
    }

    public void addUnit(String unitName) {
        this.unitNames.add(unitName);
    }
}
